/***
 * 
 * Copyright (C) 2009 Alessandro La Rosa
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: alessandro.larosa@gmail.com
 *
 * Author: Alessandro La Rosa
 */

function Rating(_id, _defaultValue)
{
	this.id = _id;
	this.ratingInput = document.getElementById(_id);
	this.value = (_defaultValue ? _defaultValue : 0);
	
	(this.ratingInput) ? this.init() : false;
}
Rating.prototype.init = function()
{
	//hide the text input
	this.ratingInput.style.display = 'none';
	
	//create the root <ul> element
	var ul = document.createElement('ul');
	ul.setAttribute('class', 'voting');
	
	//create the rating <li> element
	this.rating = document.createElement('li');
	
	//create an inner A element
	var aElement = document.createElement('a');
	aElement.href = "#";
	
	//create a SPAN for the A element
	this.handle = document.createElement('span');
	
	//create the rating value element
	this.ratingValue = document.createElement('li');
	this.ratingValue.setAttribute('class', 'voting-value');
	
	//append elements 
	aElement.appendChild(this.handle);
	this.rating.appendChild(aElement);
	ul.appendChild(this.rating);
	ul.appendChild(this.ratingValue);
	this.ratingInput.parentNode.insertBefore(ul, this.ratingInput);
	
	var self = this;
	
	// event for key-based navigation
	aElement.onkeydown = function(e)
	{
		self.handleKeyDown(e);
	}
	
	// event for touch devices
	this.rating.onclick = function(e)
	{
		self.handleClicked(e);
	}
	
	// update the component with the initial value
	this.update();
}
Rating.prototype.handleClicked = function(e)
{
	this.setValue((this.value + 1) % 6);
}
Rating.prototype.handleKeyDown = function(e)
{
	var key = e.keyCode;
	
	var newValue = this.value;
	
	if(key == 37 && this.value > 0)
		newValue--;
	else if(key == 39 && this.value < 5)
		newValue++;
	
	if(newValue != this.value)
		this.setValue(newValue);
}
Rating.prototype.setValue = function(_value)
{
	this.value = _value;
	
	this.update();
}
Rating.prototype.update = function()
{
	this.ratingInput.value = this.value;
	
	this.rating.setAttribute('class', 'voting-item voting-stars-' + this.value);
	
	this.ratingValue.innerHTML = this.value + "/5";
}
